import os, inspect, sys

def add_path_rec(path):
  abspath = os.path.abspath(path)
  if os.path.isfile(os.path.join(abspath, '__init__.py')):
    sys.path.insert(0, abspath)
    if os.path.ismount(abspath):
      return
    add_path_rec(os.path.join(abspath, '..'))

start_path = os.path.dirname(os.path.abspath(inspect.stack()[1][1]))
add_path_rec(start_path)



from distutils.core import setup
setup(
  name = 'allezup',
  packages = ['allezup'],
  version = '0.1',
  description = 'add directories above that of the source file to the python path',
  author = 'Marc Burns',
  author_email = 'm4burns@uwaterloo.ca',
  url = 'https://github.com/m4burns/allezup',
  download_url = 'https://github.com/m4burns/allezup/archive/0.1.tar.gz',
  keywords = ['module', 'package', 'import', 'path'],
  classifiers = [],
)
